@@ -93,11 +93,7 @@ class GSPeerConnectionBroadcaster:
 
             @self.sio.event
             async def watcher(id):
-                if len(rtconfiList) > 0:
-                    pc = RTCPeerConnection(configuration=RTCConfiguration(rtconfiList))
-                else:
-                    pc = RTCPeerConnection()
-
+                pc = RTCPeerConnection()
                 self.peerConnections[id] = pc
 
                 video = self.getPiH264Relay()
