@@ -57,10 +57,7 @@ class GSPeerConnectionWatcher:
 
         @self.sio.event
         async def offer(id, description):
-            if len(rtconfiList) > 0:
-                pc = RTCPeerConnection(configuration=RTCConfiguration(rtconfiList))
-            else:
-                pc = RTCPeerConnection()
+            pc = RTCPeerConnection()
 
             @self.peerConnections.on("datachannel")
             def on_datachannel(channel):
